@@ -46,17 +46,20 @@ MetaQC <- function(DList, GList, isParallel=FALSE, nCores=NULL, useCache=TRUE, f
 						requireAll("doMC")
 						registerDoMC()
 					} else { #windows
-						requireAll("doSMP")
+						requireAll("doSNOW")
 						if(is.null(getOption('cores')))
 							options(cores=2)
-						.workers <- startWorkers()
-						registerDoSMP(.workers)
+						registerDoSNOW(makeCluster(getOption('cores'), type = "SOCK"))
+						#.workers <- startWorkers()
+						#registerDoSMP(.workers)
 					}
 				}
 				
 				Cleanup <- function(.) {
-					if(!is.null(.$.workers))
-						stopWorkers(.$.workers)
+					warning("This function was deprecated.\n",
+							"No more needed to call this function.\n")
+#					if(!is.null(.$.workers))
+#						stopWorkers(.$.workers)
 				}
 				
 				.Initialize <- function(., .DList, .GList, .filterGenes) {
@@ -87,7 +90,7 @@ MetaQC <- function(DList, GList, isParallel=FALSE, nCores=NULL, useCache=TRUE, f
 				}
 				
 				.ConvertToGeneSetIdx <- function(., .DListF=.$.DListF, .GList=.$.GList, .minNumGenes=.$.minNumGenes) {
-					.DGList <- foreach(d=iter(.DListF)) %dopar% { #each data set wrap each pathway
+					.DGList <- foreach(d=iter(.DListF), .packages="foreach") %dopar% { #each data set wrap each pathway
 						.res <- foreach(g=iter(.GList)) %do% {
 							.gs <- na.omit(match(g, rownames(d)))
 							if(length(.gs)<.minNumGenes) return(NA)
@@ -327,7 +330,7 @@ MetaQC <- function(DList, GList, isParallel=FALSE, nCores=NULL, useCache=TRUE, f
 					if(is.null(.$.PathPValMat)) {
 						load(.GList)
 						.GListIdx <- .$.ConvertToGeneSetIdx(.GList=GList)
-						.PathPValList <- foreach(ii=1:length(.GListIdx)) %dopar% {
+						.PathPValList <- foreach(ii=1:length(.GListIdx), .packages="foreach") %dopar% {
 							.PathPVal <- foreach(jj=iter(.GListIdx[[ii]]), .combine=c) %do% {
 								.gnInPath <- rownames(.$.DListF[[ii]])[jj] #gene names in the pathway
 								.gMatched <- sort(match(.gnInPath, rownames(.$.PValMat0)))
@@ -390,7 +393,7 @@ MetaQC <- function(DList, GList, isParallel=FALSE, nCores=NULL, useCache=TRUE, f
 				.CalcDistOfStudies <- function(.) {
 					stopifnot(!is.null(.$.DListF))
 					
-					.$.DistOfStudies <- foreach(ii=iter(combinations(length(.$.DListF),2),by="row"), .combine=c) %dopar% {
+					.$.DistOfStudies <- foreach(ii=iter(combinations(length(.$.DListF),2),by="row"), .combine=c, .packages="foreach") %dopar% {
 						.gn <- intersect(rownames(.$.DListF[[ii[1]]]),rownames(.$.DListF[[ii[2]]]))
 						
 						.DistOfStudies <- foreach(1:100, .combine=c) %do% { #resampling based to fit practical memory limit
